@@ -1,7 +1,7 @@
 package App::Netdisco::Backend::Worker::Poller::Arpnip;
 
 use App::Netdisco::Core::Arpnip 'do_arpnip';
-use App::Netdisco::Util::Device 'is_arpnipable';
+use App::Netdisco::Util::Device 'is_arpnipable_now';
 
 use Role::Tiny;
 use namespace::clean;
@@ -9,7 +9,7 @@ use namespace::clean;
 with 'App::Netdisco::Backend::Worker::Poller::Common';
 
 sub arpnip_action { \&do_arpnip }
-sub arpnip_filter { \&is_arpnipable }
+sub arpnip_filter { \&is_arpnipable_now }
 sub arpnip_layer { 3 }
 
 sub arpwalk { (shift)->_walk_body('arpnip', @_) }
