@@ -10,13 +10,9 @@ use Socket6 (); # to ensure dependency is met
 use HTML::Entities (); # to ensure dependency is met
 use URI::QueryParam (); # part of URI, to add helper methods
 use Path::Class 'dir';
-use Module::Find ();
 use Module::Load ();
 use App::Netdisco::Util::Web 'interval_to_daterange';
 
-# can override splats only by loading first
-Module::Find::usesub 'App::NetdiscoE::Web';
-
 use App::Netdisco::Web::AuthN;
 use App::Netdisco::Web::Static;
 use App::Netdisco::Web::Search;
@@ -56,6 +52,15 @@ if (setting('extra_web_plugins') and ref [] eq ref setting('extra_web_plugins'))
 push @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
      setting('views');
 
+# any template paths in deployment.yml (should override plugins)
+if (setting('template_paths') and ref [] eq ref setting('template_paths')) {
+    push @{setting('template_paths')},
+         dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'nd-site-local', 'share')->stringify
+      if (setting('site_local_files'));
+    unshift @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
+      @{setting('template_paths')};
+}
+
 # load cookie key from database
 setting('session_cookie_key' => undef);
 my $sessions = schema('netdisco')->resultset('Session');
