@@ -17,22 +17,21 @@ register_report(
 get '/ajax/content/report/portadmindown' => require_login sub {
     my @results = schema('netdisco')->resultset('Device')->search(
         { 'up_admin' => 'down' },
-        {   result_class => 'DBIx::Class::ResultClass::HashRefInflator',
-            select       => [ 'ip', 'dns', 'name' ],
+        {   select       => [ 'ip', 'dns', 'name' ],
             join       => [ 'ports' ],
             '+columns' => [
                 { 'port'        => 'ports.port' },
                 { 'description' => 'ports.name' },
                 { 'up_admin'    => 'ports.up_admin' },
-            ],
-            order_by => { -asc => [qw/me.ip ports.port/] },
+            ]
         }
-    )->all;
+    )->hri->all;
 
     return unless scalar @results;
 
     if ( request->is_ajax ) {
-        template 'ajax/report/portadmindown.tt', { results => \@results, },
+        my $json = to_json (\@results);
+        template 'ajax/report/portadmindown.tt', { results => $json },
             { layout => undef };
     }
     else {
